@@ -11,6 +11,7 @@ static ToshibaID idList[] = {
   {0xfc0a  ,"Portage 7140CT"},
   {0xfc0b  ,"Satellite Pro 4200"},
   {0xfc0c  ,"Tecra 8100x"},
+  {0xfc0d  ,"Equium 2000"},
   {0xfc0f  ,"Satellite 2060CDS/CDT"},
   {0xfc10  ,"Satellite 2550/2590"},
   {0xfc11  ,"Portage 3110CT"},
@@ -129,7 +130,7 @@ static ToshibaID idList[] = {
   {0xfcf6  ,"R100"},
   {0xfcf7  ,"Satellite A10-213"},
   {0xfcf8  ,"Satellite A10, A20, A25-S207"},
-  {0xfcff  ,"Portege M100/M300 Tecra M2/A2/A3/M4"},
+  {0xfcff  ,"Portege M100/M300/R200 Tecra M2/A2/A3/M4"},
   {0       ,"" } 
 };
 
