@@ -20,7 +20,7 @@
  *
  */
 
-static char const rcsid[]="$Id: toshset.cc,v 1.43 2006-09-17 18:11:06 schwitrs Exp $";
+static char const rcsid[]="$Id: toshset.cc,v 1.45 2008-03-21 02:27:22 schwitrs Exp $";
 static char const rcsversion[]="$State: Exp $";
 
 
@@ -1620,6 +1620,11 @@ main(      int   argc,
  backlightFeature.addValue( "on"   , HCI_ENABLE   , "on" );
  features.append(&backlightFeature);
 
+ HciFeature trBacklightFeature(HCI_TR_BACKLIGHT,"transreflective mode");
+ trBacklightFeature.addValue( "off"  , HCI_DISABLE   , "off" );
+ trBacklightFeature.addValue( "on"   , HCI_ENABLE   , "on" );
+ features.append(&trBacklightFeature);
+
  HciFeature fanFeature(HCI_FAN,"fan");
  fanFeature.addValue( "off"  , HCI_DISABLE   , "off" );
  fanFeature.addValue( "1/4" , HCI_FAN_LOW2  , "1/4" );
@@ -1925,6 +1930,8 @@ main(      int   argc,
    new ArgSet<1>("-c","<quiet|perform> set cooling method",&coolingFeature),
    new ArgSet<1>("-bs","<setting> battery-save mode",&batteryFeature),
    new ArgSet<1>("-bl","<on|off> lcd backlight",&backlightFeature),
+   new ArgSet<1>("-trmode","<on|off> transreflective mode",
+		 &trBacklightFeature),
    new ArgSet<1>("-fan","<on|off> fan",&fanFeature),
    new ArgSet<1>("-hib","<enable|disable> hibernation",&hibernationFeature),
    new ArgSet<1>("-memsize","memory size in bytes",&hibInfoMemoryFeature),
